@@ -1,4 +1,4 @@
-# copyright 2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -358,9 +358,9 @@ class ReleditEntityFormHandler(ReleditFormHandler):
                   view_form_method):
         w = self.w
         with t.div(w, id='%s-reledit' % divid,
-                   onmouseout="jQuery('#%s').addClass('hidden')",
-                   onmouseover="jQuery('#%s').removeClass('hidden')",
-                   Class='editableFieldValue'):
+                   onmouseout="jQuery('#%s').addClass('hidden')" % divid,
+                   onmouseover="jQuery('#%s').removeClass('hidden')" % divid,
+                   Class='releditField'):
             with t.div(w, id='%s-value' % divid,
                        Class='editableFieldValue'):
                 w(value)
